C     Last change:  KC   25 Nov 2007    8:43 am
      SUBROUTINE CB08_MODEL (Mw,Rrup,Rjb,Frv,Fnm,Ztor,Dip,Vs30,Z25,Per,
     *           Y,Sigma,Tau,SigArb,SigT)

C.....
C.....PURPOSE: Evaluates Campbell-Bozorgnia NGA Model for single period
C.....
C.....MODEL VERSION: Final, March 2008 (Earthquake Spectra, Vol. 24)
C.....
C.....HISTORY
C       11/10/06 - Written by K. Campbell and Y. Bozorgnia
C       12/15/06 - Corrected values of sigc (component standard deviation)
C       11/17/07 - Updated to Earthquake Spectra version
C                - Modified to read in table of model coefficients
C                - Removed arbitrary horizontal component factor (Kc)
C.....

C.....
C.....PARAMETER DEFINITIONS
C.....

C     Mw     = Moment magnitude
C     Rrup   = Closest distance to coseismic rupture (km)
C     Rjb    = Closest distance to surface projection of coseismic rupture (km)
C     Frv    = 1 for Reverse-faulting (30 < rake < 150), 0 otherwise
C     Fnm    = 1 for Normal-faulting (-150 < rake < -30), 0 otherwise
C     Ztor   = Depth to top of coseismic rupture (km)
C     Dip    = Average dip of rupture plane (degrees)
C     Vs30   = Average shear-wave velocity in top 30m of site profile (m/s)
C     Z25    = Basin depth; depth to 2.5 km/s shear-wave velocity horizon (km)
C     Per    = Spectral period (sec), 0 for PGA, -1 for PGV, -2 for PGD
C     Y      = Ground motion parameter: PGA and PSA (g), PGV (cm/s), PGD (cm)
C     Sigma  = Intra-event standard deviation of ln Y
C     Tau    = Inter-event standard deviation of ln Y
C     SigArb = Standard deviation of arbitrary horizontal component of ln Y
C     SigT   = Standard deviation of geometric mean of ln Y

      PARAMETER (nper=24)
      REAL T(nper), c0(nper), c1(nper), c2(nper), c3(nper), c4(nper)
      REAL c5(nper), c6(nper), c7(nper), c8(nper), c9(nper), c10(nper)
      REAL c11(nper), c12(nper), k1(nper), k2(nper), k3(nper), c(nper)
      REAL n(nper), slnY(nper), tlnY(nper), slnAF(nper), sigC(nper)
      REAL rho(nper), k1T, k2T, k3T, nT, Mw

C.....
C.....READ MODEL COEFFICIENTS
C.....

      OPEN (10,FILE='CB08_COEFS.TXT')
      READ (10,'(////)')
      DO i = 1, nper
        READ (10,*) T(i),c0(i),c1(i),c2(i),c3(i),c4(i),c5(i),c6(i),
     *    c7(i),c8(i),c9(i),c10(i),c11(i),c12(i),k1(i),k2(i), k3(i),
     *    c(i),n(i),slnY(i),tlnY(i),slnAF(i),sigC(i),rho(i)
      ENDDO

C.....
C.....DETERMINE WHICH STRONG MOTION PARAMETER TO EVALUATE
C.....(PGA = 0, PGV = -1, PGD = -2, PSA = Per)
C.....

      DO i = 1, nper
        IF (Per .EQ. T(i)) THEN
          iper = i
          GOTO 1020
        ENDIF
      ENDDO

      WRITE (*,*)
      WRITE (*,*) 'ERROR: Selected period is not supported'
      WRITE (*,*)
      GOTO 999

 1020 c0T    = c0(iper)
      c1T    = c1(iper)
      c2T    = c2(iper)
      c3T    = c3(iper)
      c4T    = c4(iper)
      c5T    = c5(iper)
      c6T    = c6(iper)
      c7T    = c7(iper)
      c8T    = c8(iper)
      c9T    = c9(iper)
      c10T   = c10(iper)
      c11T   = c11(iper)
      c12T   = c12(iper)
      k1T    = k1(iper)
      k2T    = k2(iper)
      k3T    = k3(iper)
      cT     = c(iper)
      nT     = n(iper)
      slnYT  = slnY(iper)
      tlnYT  = tlnY(iper)
      slnAFT = slnAF(iper)
      sigCT  = sigC(iper)
      rhoT   = rho(iper)

C.....
C.....CALCULATE ROCK PGA (T = 0.0)
C.....
C.....Magnitude Term
C.....

      IF (Mw .LE. 5.5) THEN
        f_mag = c0(22) + c1(22)*Mw
      ELSEIF (Mw .LE. 6.5) THEN
        f_mag = c0(22) + c1(22)*Mw + c2(22)*(Mw-5.5)
      ELSE
        f_mag = c0(22) + c1(22)*Mw + c2(22)*(Mw-5.5) + c3(22)*(Mw-6.5)
      ENDIF

C.....
C.....Distance Term
C.....

      R = SQRT(Rrup**2 + c6(22)**2)
      f_dis = (c4(22) + c5(22)*Mw)*ALOG(R)

C.....
C.....Style-of-Faulting (Fault Mechanism) Term
C.....

      IF (Ztor .LT. 1.0) THEN
        f_fltZ = Ztor
      ELSE
        f_fltZ = 1.0
      ENDIF

      f_flt = c7(22)*Frv*f_fltZ + c8(22)*Fnm

C.....
C.....Hanging-Wall Term
C.....

      IF (Rjb .EQ. 0.0) THEN
        f_hngR = 1.0
      ELSEIF (Ztor .LT. 1.0) THEN
        Rmax = MAX(Rrup, SQRT(Rjb**2 + 1.0))
        f_hngR = (Rmax - Rjb)/Rmax
      ELSE
        f_hngR = (Rrup - Rjb)/Rrup
      ENDIF

      IF (Mw .LE. 6.0) THEN
        f_hngM = 0.0
      ELSEIF (Mw .LT. 6.5) THEN
        f_hngM = 2.0*(Mw - 6.0)
      ELSE
        f_hngM = 1.0
      ENDIF

      IF (Ztor .GE. 20.0) THEN
        f_hngZ = 0.0
      ELSE
        f_hngZ = (20.0 - Ztor)/20.0
      ENDIF

      IF (Dip .LE. 70.0) THEN
        f_hngD = 1.0
      ELSE
        f_hngD = (90.0 - Dip)/20.0
      ENDIF

      f_hng = c9(22)*f_hngR*f_hngM*f_hngZ*f_hngD

C.....
C.....Shallow Site Response Term (Vs30 = 1100 m/s)
C.....

      f_site = (c10(22) + k2(22)*n(22))*ALOG(1100.0/k1(22))

C.....
C.....Basin Response Term
C.....

      IF (Z25 .LT. 1.0) THEN
        f_sed = c11(22)*(Z25 - 1.0)
      ELSEIF (Z25 .LE. 3.0) THEN
        f_sed = 0.0
      ELSE
        f_sed = c12(22)*k3(22)*EXP(-0.75)*(1.0 - EXP(-0.25*(Z25 - 3.0)))
      ENDIF

C.....
C.....PGA on Rock
C.....

      A_1100 = EXP(f_mag + f_dis + f_flt + f_hng + f_site + f_sed)

C.....
C.....PGA on Local Site Conditions
C.....

      PGA = EXP(ALOG(A_1100) - f_site)
      IF (Vs30 .LT. k1(22)) THEN
        f_site = c10(22)*ALOG(Vs30/k1(22))
     *    + k2(22)*(ALOG(A_1100 + c(22)*(Vs30/k1(22))**n(22))
     *    - ALOG(A_1100 + c(22)))
      ELSEIF (Vs30 .LT. 1100.0) THEN
        f_site = (c10(22) + k2(22)*n(22))*ALOG(Vs30/k1(22))
      ELSE
        f_site = (c10(22) + k2(22)*n(22))*ALOG(1100.0/k1(22))
      ENDIF
      PGA = EXP(ALOG(PGA) + f_site)

C.....
C.....Standard Deviation of ln PGA
C.....

      slnPGA = slnY(22)
      tlnPGA = tlnY(22)

C.....
C.....CALCULATE STRONG MOTION PARAMETER
C.....
C.....Magnitude Term
C.....

      IF (Mw .LE. 5.5) THEN
        f_mag = c0T + c1T*Mw
      ELSEIF (Mw .LE. 6.5) THEN
        f_mag = c0T + c1T*Mw + c2T*(Mw-5.5)
      ELSE
        f_mag = c0T + c1T*Mw + c2T*(Mw-5.5) + c3T*(Mw-6.5)
      ENDIF
      
C.....
C.....Distance Term
C.....

      R = SQRT(Rrup**2 + c6T**2)
      f_dis = (c4T + c5T*Mw)*ALOG(R)

C.....
C.....Style-of-Faulting Term
C.....

      IF (Ztor .LT. 1.0) THEN
        f_fltZ = Ztor
      ELSE
        f_fltZ = 1.0
      ENDIF

      f_flt = c7T*Frv*f_fltZ + c8T*Fnm

C.....
C.....Hanging-Wall Term
C.....

      IF (Rjb .EQ. 0.0) THEN
        f_hngR = 1.0
      ELSEIF (Ztor .LT. 1.0) THEN
        Rmax = MAX(Rrup, SQRT(Rjb**2 + 1.0))
        f_hngR = (Rmax - Rjb)/Rmax
      ELSE
        f_hngR = (Rrup - Rjb)/Rrup
      ENDIF

      IF (Mw .LE. 6.0) THEN
        f_hngM = 0.0
      ELSEIF (Mw .LT. 6.5) THEN
        f_hngM = 2.0*(Mw - 6.0)
      ELSE
        f_hngM = 1.0
      ENDIF

      IF (Ztor .GE. 20.0) THEN
        f_hngZ = 0.0
      ELSE
        f_hngZ = (20.0 - Ztor)/20.0
      ENDIF

      IF (Dip .LE. 70.0) THEN
        f_hngD = 1.0
      ELSE
        f_hngD = (90.0 - Dip)/20.0
      ENDIF

      f_hng = c9T*f_hngR*f_hngM*f_hngZ*f_hngD 

C.....
C.....Shallow Site Response Term
C.....

      IF (Vs30 .LT. k1T) THEN
        f_site = c10T*ALOG(Vs30/k1T)
     *    + k2T*(ALOG(A_1100 + cT*(Vs30/k1T)**nT)
     *    - ALOG(A_1100 + cT))
      ELSEIF (Vs30 .LT. 1100.0) THEN
        f_site = (c10T + k2T*nT)*ALOG(Vs30/k1T)
      ELSE
        f_site = (c10T + k2T*nT)*ALOG(1100.0/k1T)
      ENDIF

C.....
C.....Basin Response Term
C.....

      IF (Z25 .LT. 1.0) THEN
        f_sed = c11T*(Z25 - 1.0)
      ELSEIF (Z25 .LE. 3.0) THEN
        f_sed = 0.0
      ELSE
        f_sed = c12T*k3T*EXP(-0.75)*(1.0 - EXP(-0.25*(Z25 - 3.0)))
      ENDIF

C.....
C.....Calculate Ground Motion Parameter
C.....

      Y = EXP(f_mag + f_dis + f_flt + f_hng + f_site + f_sed)

C.....
C.....Check Whether Y < PGA at Short Periods
C.....

      IF (Per .GE. 0.0 .AND. Per .LE. 0.25 .AND. Y .LT. PGA) Y = PGA

C.....
C.....CALCULATE ALEATORY UNCERTAINTY
C.....
C.....Linearized Relationship Between f_site and ln PGA
C.....

      IF (Vs30 .LT. k1T) THEN
        Alpha = k2T*A_1100*(1.0/(A_1100 + cT*(Vs30/k1T)**nT)
     *    - 1.0/(A_1100 + cT))
      ELSE
        Alpha = 0.0
      ENDIF

C.....
C     Intra-Event Standard Deviation at Base of Site Profile
C.....

      slnYB = SQRT(slnYT**2 - slnAFT**2)
      slnAB = SQRT(slnPGA**2 - slnAFT**2)

C.....
C     Standard Deviation of Geometric Mean of ln Y
C.....

      Sigma  = SQRT(slnYB**2 + slnAFT**2 + Alpha**2*slnAB**2
     *  + 2.0*Alpha*rhoT*slnYB*slnAB)
      Tau    = tlnYT
      SigT = SQRT(Sigma**2 + Tau**2)

C.....
C.....Standard Deviation of Arbitrary Horizontal Component of ln Y
C.....

      SigArb = SQRT(SigT**2 + sigCT**2)

  999 CLOSE (10)
      RETURN
      END

