C     Last change:  KC   19 Nov 2007    6:12 pm
      PROGRAM CB08_TABLES

C.....
C.....PURPOSE: Evaluates Campbell-Bozorgnia Example Calculation tables
C.....
C.....MODEL VERSION: Final, March 2008 (Earthquake Spectra, Vol. 24)
C.....
C.....HISTORY
C       11/10/06 - Written by K. Campbell and Y. Bozorgnia
C       12/15/06 - Corrected values of sigC in Subroutine CB06_MODEL
C       11/17/07 - Updated to Earthquake Spectra version
C                - Removed arbitrary horizontal component factor (Kc)
C.....

C.....
C.....PARAMETER DEFINITIONS
C.....

C     Mw     = Moment magnitude
C     Rrup   = Closest distance to coseismic rupture (km)
C     Rjb    = Closest distance to surface projection of coseismic rupture (km)
C     Frv    = 1 for Reverse-faulting (30 < rake < 150), 0 otherwise
C     Fnm    = 1 for Normal-faulting (-150 < rake < -30), 0 otherwise
C     Ztor   = Depth to top of coseismic rupture (km)
C     Dip    = Average dip of rupture plane (degrees)
C     Vs30   = Average shear-wave velocity in top 30m of site profile (m/s)
C     Z25    = Basin depth; depth to 2.5 km/s shear-wave velocity horizon (km)
C     Per    = Spectral period (sec), 0 for PGA, -1 for PGV, -2 for PGD
C     Y      = Ground motion parameter: PGA and PSA (g), PGV (cm/s), PGD (cm)
C     Sigma  = Intra-event standard deviation of ln Y
C     Tau    = Inter-event standard deviation of ln Y
C     SigArb = Standard deviation of arbitrary horizontal component of ln Y
C     SigT   = Standard deviation of geometric mean of ln Y

      PARAMETER (nper=5)
      REAL Rrup_M5(7), Rjb_M5_SS(7), Rjb_M5_RV(7)
      REAL Rrup_M7(9), Rjb_M7_SS(9), Rjb_M7_RV(9)
      REAL Mw, Per(5)
      CHARACTER*8 Fltype

C.....
C.....DEFINE MODEL PARAMETERS
C.....

      DATA Rrup_M5   /5., 10., 15., 30., 50., 100., 200./
      DATA Rrup_M7   /1., 3., 5., 10., 15., 30., 50., 100., 200./
      DATA Rjb_M5_SS /0., 8.7, 14.1, 29.6, 49.7, 99.9, 199.9/
      DATA Rjb_M5_RV /0., 7., 13.2, 29.1, 49.5, 99.7, 199.9/
      DATA Rjb_M7_SS /1., 3., 5., 10., 15., 30., 50., 100., 200./
      DATA Rjb_M7_RV /0., 0., 0., 0., 6.2, 26., 47.7, 98.9, 199.4/
      DATA Per       /.01, .2, 1., 3., -1./

      OPEN (11,FILE='CB08_TABLES.OUT')

C.....
C.....EVALUATE CB08 FOR STRIKE-SLIP FAULTING CASE
C.....

      Frv = 0.0
      Fnm = 0.0
      Dip = 90.0
      Vs30 = 760.0
      Z25 = 2.0

      DO iper = 1, nper

        Mw = 5.0
        Ztor = 5.0
        Fltype = 'SS'
        WRITE (11,100) Per(iper),Mw,Fltype,Frv,Fnm,Ztor,Dip,Vs30,Z25
        DO idis = 1, 7
          CALL CB08_MODEL (Mw,Rrup_M5(idis),Rjb_M5_SS(idis),Frv,Fnm,
     *         Ztor,Dip,Vs30,Z25,Per(iper),Y,Sigma,Tau,SigArb,SigT)
          WRITE (11,200) Rrup_M5(idis),Rjb_M5_SS(idis),Y,Sigma,Tau,
     *          SigT,SigArb
        ENDDO

        Mw = 7.0
        Ztor = 0.0
        Fltype = 'SS'
        WRITE (11,100) Per(iper),Mw,Fltype,Frv,Fnm,Ztor,Dip,Vs30,Z25
        DO idis = 1, 9
          CALL CB08_MODEL (Mw,Rrup_M7(idis),Rjb_M7_SS(idis),Frv,Fnm,
     *         Ztor,Dip,Vs30,Z25,Per(iper),Y,Sigma,Tau,SigArb,SigT)
          WRITE (11,200) Rrup_M7(idis),Rjb_M7_SS(idis),Y,Sigma,Tau,
     *          SigT,SigArb
        ENDDO

      ENDDO

C.....
C.....EVALUATE CB08 FOR REVERSE FAULTING CASE
C.....

      Frv = 1.0
      Fnm = 0.0
      Dip = 45.0
      Vs30 = 760.0
      Z25 = 2.0

      DO iper = 1, nper

        Mw = 5.0
        Ztor = 5.0
        Fltype = 'RV'
        WRITE (11,100) Per(iper),Mw,Fltype,Frv,Fnm,Ztor,Dip,Vs30,Z25
        DO idis=1,7
          CALL CB08_MODEL (Mw,Rrup_M5(idis),Rjb_M5_RV(idis),Frv,Fnm,
     *         Ztor,Dip,Vs30,Z25,Per(iper),Y,Sigma,Tau,SigArb,SigT)
          WRITE (11,200) Rrup_M5(idis), Rjb_M5_RV(idis),Y,Sigma,Tau,
     *          SigT,SigArb
        ENDDO

        Mw = 7.0
        Ztor = 0.0
        Fltype = 'RV'
        WRITE (11,100) Per(iper),Mw,Fltype,Frv,Fnm,Ztor,Dip,Vs30,Z25
        DO idis = 1, 9
          CALL CB08_MODEL (Mw,Rrup_M7(idis),Rjb_M7_RV(idis),Frv,Fnm,
     *         Ztor,Dip,Vs30,Z25,Per(iper),Y,Sigma,Tau,SigArb,SigT)
          WRITE (11,200) Rrup_M7(idis),Rjb_M7_RV(idis),Y,Sigma,Tau,
     *          SigT,SigArb
        ENDDO

      ENDDO


  100 FORMAT (/'T=',f6.3,' Mw=',f3.1,' Flt=',a2,' Frv=',f3.1,' Fnm=',
     *       f3.1,' Ztor=',f4.1,' Dip=',f4.1,' Vs30=',f6.1,' Z25=',f4.1,
     *       //1x'Rrup',6x,'Rjb',7x,'Y(g)',6x,'Sigma',5x,'Tau',7x,
     *       'SigT',6x,'SigArb')
  200 FORMAT (1P,7(E10.3))

      CLOSE (11)
      END PROGRAM
